@@ -1,5 +1,7 @@
 """
-Main interface for amp service client paginators.
+Type annotations for amp service client paginators.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/paginators.html)
 
 Usage::
 
@@ -27,12 +29,13 @@ __all__ = ("ListWorkspacesPaginator",)
 
 class ListWorkspacesPaginator(Boto3Paginator):
     """
-    [Paginator.ListWorkspaces documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/paginators.html#listworkspacespaginator)
     """
 
     def paginate(
         self, alias: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListWorkspacesResponseTypeDef]:
         """
-        [ListWorkspaces.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/paginators.html#listworkspacespaginator)
         """
